@@ -36,10 +36,12 @@ static const char key_names[] =
   "recent_games_list\0"
   "show_toolbar\0"
   "click_to_move\0"
-  "sound";
+  "sound\0"
+  "show_statusbar\0"
+  "animations";
 
 static const guint8 key_name_offsets[] = {
-  0, 11, 21, 39, 52, 66
+  0, 11, 21, 39, 52, 66, 72, 87
 };
 
 static const char statistics_key[] = "/apps/aisleriot/statistics";
@@ -52,16 +54,18 @@ static const char key_names[] =
   "Recent\0"
   "ShowToolbar\0"
   "ClickToMove\0"
-  "Sound";
+  "Sound\0"
+  "ShowStatusbar\0"
+  "Animations";
 
 static const guint8 key_name_offsets[] = {
-  0, 6, 16, 23, 35, 47
+  0, 6, 16, 23, 35, 47, 53, 67
 };
 
 #endif /* HAVE_GNOME */
 
 #ifdef HAVE_GNOME
-  
+
 static GConfClient *gconf_client;
 static GHashTable *stats;
 
@@ -172,6 +176,9 @@ aisleriot_conf_init (void)
   if (!games_conf_initialise ("Aisleriot")) {
     /* Set defaults */
     games_conf_set_boolean (NULL, aisleriot_conf_get_key (CONF_SHOW_TOOLBAR), TRUE);
+    games_conf_set_boolean (NULL, aisleriot_conf_get_key (CONF_SHOW_STATUSBAR), TRUE);
+    games_conf_set_boolean (NULL, aisleriot_conf_get_key (CONF_SOUND), TRUE);
+    games_conf_set_boolean (NULL, aisleriot_conf_get_key (CONF_ANIMATIONS), TRUE);
 
 #ifdef HAVE_HILDON
     games_conf_set_boolean (NULL, aisleriot_conf_get_key (CONF_CLICK_TO_MOVE), TRUE);
@@ -304,6 +311,17 @@ aisleriot_conf_get_statistic (const char *game_file,
   AisleriotStatistic *game_stat;
 
   game_stat = g_hash_table_lookup (stats, game_file);
+  if (!game_stat) {
+    char *display_name;
+
+    /* Previous versions used the localised name as key, so try it as fall-back.
+     * See bug #406267 and bug #525177.
+     */
+    display_name = aisleriot_util_get_display_filename (game_file);
+    game_stat = g_hash_table_lookup (stats, display_name);
+    g_free (display_name);
+  }
+
   if (game_stat) {
     *statistic = *game_stat;
   } else {
