@@ -1,4 +1,4 @@
-import ConfigParser
+# -*- coding: utf-8 -*-
 import os
 import socket
 import errno
@@ -22,36 +22,64 @@ class GGZConfig:
     TYPE_FIRST  = 2
     
     def __init__(self):
-        parser = ConfigParser.SafeConfigParser()
-        parser.read(GGZ_CONFIG_FILE)
+        try:
+            lines = file(GGZ_CONFIG_FILE).readlines()
+        except IOError:
+            print 'Failed to load GGZ config'
+            lines = []
+        fields = {}
+        section = None
+        for l in lines:
+            l = l.strip()
+            
+            # Skip empty lines or comments
+            if len(l) == 0 or l[0] == '#':
+                continue
+            
+            # Look for section headers
+            if l[0] == '[':
+                if l[-1] != ']':
+                    print 'Invalid section line: %s' % repr(l)
+                    continue
+                section = l[1:-1]
+                if not fields.has_key(section):
+                    fields[section] = {}
+                continue
+            
+            try:
+                (name, value) = l.split('=', 1)
+            except ValueError:
+                print 'Invalid field line: %s' % repr(l)
+            else:
+                fields[section][name.strip()] = value.strip()
 
         self.servers = []
         try:
-            value = parser.get('Servers', 'profilelist')
-        except ConfigParser.NoSectionError:
+            value = fields['Servers']['ProfileList']
+        except KeyError:
             pass
         else:
             for n in value.replace('\\ ', '\x00').split(' '):
                 server = GGZServer()
                 server.name = n.replace('\x00', ' ')
                 
-                if not parser.has_section(server.name):
+                if not fields.has_key(server.name):
                     print 'Missing server section %s' % repr(server.name)
                     continue
             
                 try:
-                    server.host = parser.get(server.name, 'Host')
-                    server.port = parser.getint(server.name, 'Port')
-                    server.login = parser.get(server.name, 'Login')
-                    server.loginType = parser.getint(server.name, 'Type')
-                except ConfigParser.NoOptionError:
-                    print 'Missing basic configuration for server %s' % repr(server.name)
+                    server.host = fields[server.name]['Host']
+                    server.port = int(fields[server.name]['Port'])
+                    server.login = fields[server.name]['Login']
+                    server.loginType = int(fields[server.name]['Type'])
+                except (KeyError, ValueError):
+                    print 'Missing/invalid basic configuration for server %s' % repr(server.name)
                     continue
-                
+
                 try:
-                    server.password = parser.get(server.name, 'Password')
-                except ConfigParser.NoOptionError:
-                    server.password = ''
+                    server.password = fields[server.name]['Password']
+                except KeyError:
+                    server.password = None
 
                 self.servers.append(server)
                 
@@ -154,8 +182,8 @@ class GGZConnection(ggz.ClientFeedback):
             method(*args)
 
     def close(self):
-        self.client.close()
-        
+        self.client.close('')
+
     def setBusy(self, isBusy):
         self.dialog.controller.setBusy(isBusy)
         
@@ -168,8 +196,8 @@ class GGZConnection(ggz.ClientFeedback):
         self.dialog.controller.setSensitive(True)
         self.dialog.controller.clearError()
 
-    def onDisconnected(self):
-        self.dialog.controller.setError(_('Disconnected'), _('You have been disconnected from the server'))
+    def onDisconnected(self, reason):
+        self.dialog.controller.setError(_('Disconnected from server'), reason)
         self.dialog.controller.setSensitive(False)
 
     def openChannel(self, feedback):
@@ -179,11 +207,11 @@ class GGZConnection(ggz.ClientFeedback):
         socket.connect(self.profile.host, self.profile.port)
         return socket
 
-    def getUsername(self):
-        return  self.profile.login
+    def getLogin(self):
+        return (self.profile.login, self.profile.password)
     
     def getPassword(self, username):
-        return self.profile.password
+        self.client.setPassword(self.profile.password)
         
     def onMOTD(self, motd):
         self.dialog.controller.addText(motd, 'motd')
@@ -247,7 +275,7 @@ class GGZConnection(ggz.ClientFeedback):
         self.dialog.controller.joinTable(None)
 
     def playerAdded(self, player):
-        self.dialog.controller.addPlayer(player.name, player, self._getPlayerIcon(player))
+        self.dialog.controller.addPlayer(player, player.name, self._getPlayerIcon(player))
 
     def playerRemoved(self, player):
         self.dialog.controller.removePlayer(player)
