@@ -1,4 +1,4 @@
-/* -*- mode:C; indent-tabs-mode:nill; tab-width:8; c-basic-offset:8 -*- */
+/* -*- mode:C++; tab-width:8; c-basic-offset:8; indent-tabs-mode:true -*- */
 /*
  * written by J. Marcin Gorycki <marcin.gorycki@intel.com>
  *
@@ -21,19 +21,24 @@
 
 #include "blockops.h"
 #include "blocks.h"
+
+#ifdef HAVE_CLUTTER
 #include "field.h"
+#else
+#include "field-noclutter.h"
+#endif
 
 #define NCOLOURS 7
 
 
 BlockOps::BlockOps() :
-     blocknr (0),
-     rot (0),
-     color (0),
-     useTarget (false)
+	useTarget (false),
+	blocknr (0),
+	rot (0),
+	color (0)
 {
 	field = new Block*[COLUMNS];
-	
+
 	posx = COLUMNS / 2;
 	posy = 0;
 
@@ -47,11 +52,11 @@ BlockOps::~BlockOps()
 {
 	for (int i = 0; i < COLUMNS; ++i)
 		delete[] field[i];
-	
+
 	delete[] field;
 }
 
-bool 
+bool
 BlockOps::blockOkHere(int x, int y, int b, int r)
 {
 	x -= 2;
@@ -71,14 +76,14 @@ BlockOps::blockOkHere(int x, int y, int b, int r)
 		}
 	}
 
-	return true;	
+	return true;
 }
 
 int
 BlockOps::getLinesToBottom()
 {
 	int lines = LINES;
-	
+
 	for (int x = 0; x < 4; ++x)
 	{
 		for (int y = 3; y >= 0; --y)
@@ -100,7 +105,7 @@ BlockOps::getLinesToBottom()
 	return lines;
 }
 
-bool 
+bool
 BlockOps::moveBlockLeft()
 {
 	bool moved = false;
@@ -112,11 +117,11 @@ BlockOps::moveBlockLeft()
 		putBlockInField(false);
 		moved = true;
 	}
-	
+
 	return moved;
 }
 
-bool 
+bool
 BlockOps::moveBlockRight()
 {
 	bool moved = false;
@@ -128,7 +133,7 @@ BlockOps::moveBlockRight()
 		putBlockInField(false);
 		moved = true;
 	}
-	
+
 	return moved;
 }
 
@@ -136,9 +141,9 @@ bool
 BlockOps::rotateBlock(bool rotateCCW)
 {
 	bool moved = false;
-	
+
 	int r = rot;
-	
+
 	if ( rotateCCW )
 	{
 		if (--r < 0) r = 3;
@@ -147,7 +152,7 @@ BlockOps::rotateBlock(bool rotateCCW)
 	{
 		if (++r >= 4) r = 0;
 	}
-		
+
 	if (blockOkHere(posx, posy, blocknr, r))
 	{
 		putBlockInField(true);
@@ -155,11 +160,11 @@ BlockOps::rotateBlock(bool rotateCCW)
 		putBlockInField(false);
 		moved = true;
 	}
-	
+
 	return moved;
 }
 
-bool 
+bool
 BlockOps::moveBlockDown()
 {
 	bool fallen = false;
@@ -173,11 +178,11 @@ BlockOps::moveBlockDown()
 		++posy;
 		putBlockInField(false);
 	}
-	
+
 	return fallen;
 }
 
-void 
+void
 BlockOps::clearTarget ()
 {
 	for (int x = 0; x < COLUMNS; ++x)
@@ -197,7 +202,7 @@ BlockOps::generateTarget ()
 	clearTarget ();
 
 	// FIXME: Check that this is actually guaranteed
-	// to terminate (i.e. posx, posy, blocknr and rot 
+	// to terminate (i.e. posx, posy, blocknr and rot
 	// are guaranteed to be valid).
 	int n = 0;
 	do {
@@ -209,7 +214,7 @@ BlockOps::generateTarget ()
 	putBlockInField (posx, posy + n, blocknr, rot, TARGET);
 }
 
-void 
+void
 BlockOps::setUseTarget (bool use)
 {
 	useTarget = use;
@@ -220,12 +225,12 @@ BlockOps::setUseTarget (bool use)
 int
 BlockOps::dropBlock()
 {
-        int count = 0;
-  
+	int count = 0;
+
 	while (!moveBlockDown())
 		count++;
 
-        return count;
+	return count;
 }
 
 void
@@ -301,12 +306,12 @@ BlockOps::generateFallingBlock()
 	int cn = random_block_colors ? g_random_int_range(0, NCOLOURS) :
 		blocknr % NCOLOURS;
 	color = color_next == -1 ? cn : color_next;
-	
+
 	blocknr_next = g_random_int_range(0, tableSize);
 	rot_next = g_random_int_range(0, 4);
 	color_next = random_block_colors ? g_random_int_range(0, NCOLOURS) :
 		blocknr_next % NCOLOURS;
-	
+
 	if (!blockOkHere(posx, posy, blocknr, rot))
 		return false;
 
@@ -320,18 +325,18 @@ BlockOps::emptyField(int filled_lines, int fill_prob)
 
 	for (int y = 0; y < LINES; ++y)
 	{
- 		// Allow for at least one blank per line
+		// Allow for at least one blank per line
 		blank = g_random_int_range(0, COLUMNS);
 
 		for (int x = 0; x < COLUMNS; ++x)
 		{
 			field[x][y].what = EMPTY;
-			field[x][y].color = 0; 
+			field[x][y].color = 0;
 
 			if ((y>=(LINES - filled_lines)) && (x != blank) &&
-			    ((g_random_int_range(0, 10)) < fill_prob)) { 
+			    ((g_random_int_range(0, 10)) < fill_prob)) {
 				field[x][y].what = LAYING;
-				field[x][y].color = 
+				field[x][y].color =
 				  g_random_int_range(0, NCOLOURS);
 			}
 		}
@@ -357,7 +362,7 @@ BlockOps::putBlockInField (int bx, int by, int block, int rotation,
 				int i = bx - 2 + x;
 				int j = y + by;
 
-				if ((fill == TARGET) && 
+				if ((fill == TARGET) &&
 				    (field[i][j].what != EMPTY))
 					return;
 
@@ -386,10 +391,10 @@ BlockOps::putBlockInField (bool erase)
 bool
 BlockOps::isFieldEmpty (void)
 {
-  for (int x = 0; x < COLUMNS; x++) {
-    if (field[x][LINES-1].what != EMPTY)
-      return false;
-  }
+	for (int x = 0; x < COLUMNS; x++) {
+		if (field[x][LINES-1].what != EMPTY)
+			return false;
+	}
 
-  return true;
+	return true;
 }
