@@ -21,7 +21,6 @@
  */
 
 #include "preview.h"
-#include "blocks.h"
 
 #define PREVIEW_WIDTH 6
 #define PREVIEW_HEIGHT 6
@@ -46,15 +45,14 @@ Preview::Preview():
 		}
 	}
 
-	w = gtk_drawing_area_new();
+	w = gtk_clutter_embed_new();
 
-	g_signal_connect (w, "expose_event", G_CALLBACK (expose), this);
 	g_signal_connect (w, "configure_event", G_CALLBACK (configure), this);
 
 	/* FIXME: We should scale with the rest of the UI, but that requires
-	 * changes to the widget layout - i.e. wrap the preview in an 
+	 * changes to the widget layout - i.e. wrap the preview in an
 	 * fixed-aspect box. */
-	gtk_widget_set_size_request (w, PREVIEW_SIZE * 20, 
+	gtk_widget_set_size_request (w, PREVIEW_SIZE * 20,
 				     PREVIEW_SIZE * 20);
 
 	gtk_widget_show (w);
@@ -72,7 +70,6 @@ void
 Preview::enable(bool en)
 {
 	enabled = en;
-	gtk_widget_queue_draw (w);
 }
 
 void
@@ -92,7 +89,7 @@ Preview::previewBlock(int bnr, int brot, int bcolor)
 
 	for (x = 1; x < PREVIEW_WIDTH - 1; x++) {
 		for (y = 1; y < PREVIEW_HEIGHT - 1; y++) {
-			if ((blocknr != -1) && 
+			if ((blocknr != -1) &&
 			    blockTable[blocknr][blockrot][x-1][y-1]) {
 				blocks[x][y].what = LAYING;
 				blocks[x][y].color = blockcolor;
@@ -117,12 +114,12 @@ Preview::configure(GtkWidget * widget, GdkEventConfigure * event, Preview * prev
 	if (preview->background)
 		cairo_surface_destroy (preview->background);
 
-	preview->background = 
+	preview->background =
 		cairo_surface_create_similar (cairo_get_target (cr),
 					      CAIRO_CONTENT_COLOR,
 					      event->width,
 					      event->height);
-	
+
 	cairo_destroy (cr);
 
 	cr = cairo_create (preview->background);
@@ -133,49 +130,3 @@ Preview::configure(GtkWidget * widget, GdkEventConfigure * event, Preview * prev
 	return TRUE;
 }
 
-gint
-Preview::expose(GtkWidget * widget, GdkEventExpose * event, Preview * preview)
-{
-	cairo_t *cr;
-	Renderer *r;
-
-	cr = gdk_cairo_create (widget->window);
-
-	if (!preview->enabled)
-	{
-		cairo_scale (cr, 1.0*widget->allocation.width/PREVIEW_WIDTH,
-			     1.0*widget->allocation.height/PREVIEW_HEIGHT);
-		cairo_set_line_cap (cr, CAIRO_LINE_CAP_ROUND);
-
-		cairo_set_source_rgb (cr, 0, 0, 0);
-		cairo_paint (cr);
-
-		cairo_set_source_rgb (cr, 0.8, 0.1, 0.1);
-		cairo_set_line_width (cr, 0.5);
-
-		cairo_move_to (cr, 1, 1);
-		cairo_line_to (cr, PREVIEW_WIDTH-1, PREVIEW_HEIGHT-1);
-		cairo_move_to (cr, PREVIEW_WIDTH-1, 1);
-		cairo_line_to (cr, 1, PREVIEW_HEIGHT-1);
-
-		cairo_stroke (cr);
-	}
-	else 
-	{
-		cairo_surface_t *dst;
-		
-		dst = cairo_get_target (cr);
-
-		r = rendererFactory (preview->themeID, dst, 
-				     preview->background, preview->blocks,
-				     PREVIEW_WIDTH, PREVIEW_HEIGHT,
-				     preview->width, preview->height);
-
-		r->render ();
-		delete r;
-	}
-
-	cairo_destroy (cr);
-
-	return TRUE;
-}
