@@ -1,3 +1,4 @@
+/* -*- mode:C++; tab-width:8; c-basic-offset:8; indent-tabs-mode:true -*- */
 #ifndef __preview_h__
 #define __preview_h__
 
@@ -24,38 +25,41 @@
 #include "tetris.h"
 #include "blockops.h"
 #include "renderer.h"
+#include "blocks.h"
+
+#include <clutter-gtk/gtk-clutter-embed.h>
+#include <clutter-cairo/clutter-cairo.h>
 
 class Preview {
 public:
-  Preview ();
-  ~Preview ();
+	Preview ();
+	~Preview ();
 
-  GtkWidget *getWidget () {
-    return w;
-  } void enable (bool enable);
-  void previewBlock (int bnr, int brot, int bcolor);
-  void setTheme (int id);
+	GtkWidget *getWidget () {
+		return w;
+	}
+
+	void enable (bool enable);
+	void previewBlock (int bnr, int brot, int bcolor);
+	void setTheme (int id);
 
 private:
-  GtkWidget * w;
-  gint width;
-  gint height;
+	GtkWidget * w;
+	gint width;
+	gint height;
 
-  int blocknr;
-  int blockrot;
-  int blockcolor;
+	int blocknr;
+	int blockrot;
+	int blockcolor;
 
-  bool enabled;
+	bool enabled;
 
-  int themeID;
-  cairo_surface_t *background;
+	int themeID;
+	cairo_surface_t *background;
 
-  static gint configure (GtkWidget * widget, GdkEventConfigure * event,
-			 Preview * preview);
-  static gint expose (GtkWidget * widget, GdkEventExpose * event,
-		      Preview * preview);
-
-  Block **blocks;
+	static gint configure (GtkWidget * widget, GdkEventConfigure * event,
+			       Preview * preview);
+	Block **blocks;
 };
 
 #endif //__preview_h__
